function [ ] = CreateLongDynamicPlots( strc  )
%% Figure 12 - Longitudinal Dynamics
ColorsSpeed1{1} = [1 0 0];
ColorsSpeed1{2} = [0.3 0.3 1];
ColorsSpeed2{1} = [1 0.4 0.4];
ColorsSpeed2{2} = [0.7 0.7 1];
LineStyle{1}    = '-';
LineStyle{2}    = ':';
threshold1      = 0; % km/h
threshold2      = 150;
bins            = 0:2:70;
brake_bins      = -40:2:0;
h               = cell(2,1); % line properties used for legend

figure(); hold on
for cond = 1:2
    % Init for each condition
    XTcomb       = []; % Combined throttle signal
    XBcomb       = []; % Combined Brake signal
    LongAccComb  = []; % Combined long acc signal
    
    for rep = 1:4
        speed1 = strc.Experiment{1}.sub.cond(cond).rep(rep).VehicleSpeed./3.6;
        speed_id1 = find(speed1> (threshold1./3.6) & speed1< (threshold2./3.6) );
        
        Xg1 = strc.Experiment{1}.sub.cond(cond).rep(rep).RawSensor(speed_id1);
        Xb1 = -strc.Experiment{1}.sub.cond(cond).rep(rep).BrakingPressure(speed_id1);
        Y1 = strc.Experiment{1}.sub.cond(cond).rep(rep).LongitudinalAcceler(speed_id1);
        h{cond} = plot(Xg1,Y1,'color',ColorsSpeed2{cond});
        plot(Xb1,Y1,'color',ColorsSpeed2{cond});
        
        speed2 = strc.Experiment{2}.sub.cond(cond).rep(rep).VehicleSpeed./3.6;
        speed_id2 = find(speed2>(threshold1./3.6) & speed2<(threshold2./3.6));
        
        Xg2 = strc.Experiment{2}.sub.cond(cond).rep(rep).RawSensor(speed_id2);
        Xb2 = -strc.Experiment{2}.sub.cond(cond).rep(rep).BrakingPressure(speed_id2);
        Y2 = strc.Experiment{2}.sub.cond(cond).rep(rep).LongitudinalAcceler(speed_id2);
        plot(Xg2,Y2,'color',ColorsSpeed2{cond});
        plot(Xb2,Y2,'color',ColorsSpeed2{cond});
        
        XTcomb = [XTcomb Xg1' Xg2'];
        XBcomb = [XBcomb Xb1' Xb2'];
        LongAccComb  = [LongAccComb Y1' Y2'];
    end
     
    for jj = 1:length(bins)-1
        id =  XTcomb < bins(jj+1) & XTcomb > bins(jj) ;
        YTid = LongAccComb(id);
        LongAcc_t{cond}.mean(jj) = mean(YTid);
        
        if jj<length(brake_bins)
            idb =  XBcomb < brake_bins(jj+1) & XBcomb > brake_bins(jj) ;
            Ybid = LongAccComb(idb);
            LongAcc_b{cond}.mean(jj) = mean(Ybid);
        end
        
    end
    
end
% Throttle
plot(bins(1:end-1),LongAcc_t{1}.mean,LineStyle{1},'color',ColorsSpeed1{1},'LineWidth',3)
plot(bins(1:end-1),LongAcc_t{2}.mean,LineStyle{2},'color',ColorsSpeed1{2},'LineWidth',3)

% Brake
hs = plot(brake_bins(2:end),LongAcc_b{1}.mean,LineStyle{1},'color',ColorsSpeed1{1},'LineWidth',3);
hc = plot(brake_bins(2:end),LongAcc_b{2}.mean,LineStyle{2},'color',ColorsSpeed1{2},'LineWidth',3);

xlabel('Brake (bar)                                       Throttle (%)');
ylabel('Longitudinal acceleration (m/s^2)')
legend([hs, hc],'Sport','Comfort')
ylim([-5 3])
xlim([-25 60])
xticks([-20 -10 0 10 20 30 40 50 60])
xticklabels({'20','10','0','10','20','30','40','50','60'})
end