function [ ] = CreateSlopePlots( strc, exp  )
%% Initialize
exp.strc      = strc;
MetricNames_2 = {'RearWheelAnglePosit','YawRate','TransversalAccelera'};
MetricName1   = 'SteeringWheelAngle'; 

% loop to create multiple figures using the same code but different metric
for jj = 1:length(MetricNames_2) 
    % Initialize for each signal name
    stepsize      = 5;
    Slope_sport   = nan(22,1); % slopes for the different speed bins in sport
    Slope_comf    = nan(22,1); % slopes for the different speed bins in comfort
    bins          = 0:stepsize:110; % Steps of 5 km/h
    MetricName2   = MetricNames_2{jj};
    Speed{1}      = []; 
    Speed{2}      = []; 
    peed_ms{1}    = []; 
    peed_ms{2}    = [];
    Mx{1}         = []; 
    My{1}         = []; 
    Mx{2}         = []; 
    My{2}         = [];
    
    % Combine data into one vector
    for i = 1:exp.total_rep
        Speed{1} = [Speed{1};exp.strc.Experiment{1}.sub.cond(1).rep(i).VehicleSpeed;exp.strc.Experiment{2}.sub.cond(1).rep(i).VehicleSpeed];
        Speed{2} = [Speed{2};exp.strc.Experiment{1}.sub.cond(2).rep(i).VehicleSpeed;exp.strc.Experiment{2}.sub.cond(2).rep(i).VehicleSpeed];
        eval(['Mx{1} = [Mx{1};exp.strc.Experiment{1}.sub.cond(1).rep(i).' MetricName1 ';exp.strc.Experiment{2}.sub.cond(1).rep(i).' MetricName1 '];']);
        eval(['My{1} = [My{1};exp.strc.Experiment{1}.sub.cond(1).rep(i).' MetricName2 ';exp.strc.Experiment{2}.sub.cond(1).rep(i).' MetricName2 '];']);
        eval(['Mx{2} = [Mx{2};exp.strc.Experiment{1}.sub.cond(2).rep(i).' MetricName1 ';exp.strc.Experiment{2}.sub.cond(2).rep(i).' MetricName1 '];']);
        eval(['My{2} = [My{2};exp.strc.Experiment{1}.sub.cond(2).rep(i).' MetricName2 ';exp.strc.Experiment{2}.sub.cond(2).rep(i).' MetricName2 '];']);
    end
    
    if strcmp(MetricName2,'YawRate')
        My{1} = My{1}; My{2} = My{2};
    end
    if strcmp(MetricName2,'TransversalAccelera')
        My{1} = My{1}.*9.80665; My{2} = My{2}.*9.80665;
    end
    Speed_ms{1} = Speed{1}./3.6; Speed_ms{2} = Speed{2}./3.6;
    
    % put in bins
    for i = 1:length(bins)-1
        id1 = find(Speed{1} < bins(i+1) & Speed{1} > bins(i));
        id2 = find(Speed{2} < bins(i+1) & Speed{2} > bins(i));
        
        f1_temp = fit(Mx{1}(id1),My{1}(id1),'poly1');
        f2_temp = fit(Mx{2}(id2),My{2}(id2),'poly1');
        
        Slope_sport(i) = f1_temp.p1;
        Slope_comf(i)  = f2_temp.p1;
    end
    
    figure(); hold on;
    h1 = plot((bins(2:end)-stepsize/2),Slope_sport,'^-','LineWidth',2,'color',[1 0 0],'MarkerFaceColor',[1 0 0]);
    h2 = plot((bins(2:end)-stepsize/2),Slope_comf,'o-','color',[0.6 0.6 1],'LineWidth',2,'MarkerFaceColor',[0.6 0.6 1]);
    
    if strcmp(MetricName2,'RearWheelAnglePosit')
        plot([0 110],[0 0],'k--','LineWidth',2);
    end
    xlabel('Speed (km/h)')
    if jj == 1
        ylabel({'Slope of','SW Angle (deg) vs Rear Wheel Angle (deg)'})
    elseif jj == 2
        ylabel({'Slope of','SW Angle (deg) vs YawRate (deg/sec)'})
    elseif jj == 3
        ylabel({'Slope of','SW Angle (deg) vs Lateral acceleration (m/s^2)'})
    end
    legend([h1,h2],'Sport','Comfort')
    xlim([0 110])
    fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',13)
end
end