function [ ] = CreateSpeedBinPlots( strc  )
%% Figure 9a - Rear wheel angle
ColorsSpeed1{1} = [1 0 0];
ColorsSpeed1{2} = [0.5 0.5 1];
ColorsSpeed2{1} = [1 0.6 0.6];
ColorsSpeed2{2} = [0.8 0.8 1];
Xfit{1} = []; Yfit{1} = [];
Xfit{2} = []; Yfit{2} = [];

% Rearwheel angle
figure(); hold on
for cond = 1:2
    for rep = 1:4
        speed1 = strc.Experiment{1}.sub.cond(cond).rep(rep).VehicleSpeed;
        speed_id1 = find(speed1>20 & speed1<30);
        
        X1 = strc.Experiment{1}.sub.cond(cond).rep(rep).SteeringWheelAngle(speed_id1);
        Y1 = strc.Experiment{1}.sub.cond(cond).rep(rep).RearWheelAnglePosit(speed_id1);
        
        speed2 = strc.Experiment{2}.sub.cond(cond).rep(rep).VehicleSpeed;
        speed_id2 = find(speed2>20 & speed2<30);
        
        X2 = strc.Experiment{2}.sub.cond(cond).rep(rep).SteeringWheelAngle(speed_id2);
        Y2 = strc.Experiment{2}.sub.cond(cond).rep(rep).RearWheelAnglePosit(speed_id2);
        
        Xfit{cond} = [Xfit{cond};X1;X2];
        Yfit{cond} = [Yfit{cond};Y1;Y2];
    end
end

f1 = fit(Xfit{1},Yfit{1},'poly1');
f2 = fit(Xfit{2},Yfit{2},'poly1');

% Scatter
h1{1} = scatter(Xfit{1},Yfit{1},8,ColorsSpeed2{1},'filled');
h1{2} = scatter(Xfit{2},Yfit{2},8,ColorsSpeed2{2},'filled');

% regression fit
x = linspace(-200,140,20);
plot(x,x.*f1.p1 + f1.p2,'--','color',[0.7 0.7 0.7]);
plot(x,x.*f2.p1 + f2.p2,'--','color',[0.7 0.7 0.7]);

text(145,145.*f1.p1 + f1.p2,['a_{sport 20-30} = ' num2str(round(f1.p1,3))]);
text(145,145.*f2.p1 + f2.p2,['a_{comfort 20-30} = ' num2str(round(f2.p1,3))]);

Xfit{1} = []; Yfit{1} = [];
Xfit{2} = []; Yfit{2} = [];

% speed 2
for cond = 1:2
    for rep = 1:4
        speed1 = strc.Experiment{1}.sub.cond(cond).rep(rep).VehicleSpeed;
        speed_id1 = find(speed1>80 & speed1<90);
        
        X1 = strc.Experiment{1}.sub.cond(cond).rep(rep).SteeringWheelAngle(speed_id1);
        Y1 = strc.Experiment{1}.sub.cond(cond).rep(rep).RearWheelAnglePosit(speed_id1);

        speed2 = strc.Experiment{2}.sub.cond(cond).rep(rep).VehicleSpeed;
        speed_id2 = find(speed2>80 & speed2<90);
        
        X2 = strc.Experiment{2}.sub.cond(cond).rep(rep).SteeringWheelAngle(speed_id2);
        Y2 = strc.Experiment{2}.sub.cond(cond).rep(rep).RearWheelAnglePosit(speed_id2);

        Xfit{cond} = [Xfit{cond};X1;X2];
        Yfit{cond} = [Yfit{cond};Y1;Y2];
    end
end

% Scatter
h2{1} = scatter(Xfit{1},Yfit{1},8,ColorsSpeed1{1},'filled');
h2{2} = scatter(Xfit{2},Yfit{2},8,ColorsSpeed1{2},'filled');

% Linear fit
f1 = fit(Xfit{1},Yfit{1},'poly1');
f2 = fit(Xfit{2},Yfit{2},'poly1');

x = linspace(-200,120,20);
plot(x,x.*f1.p1 + f1.p2,'*-','color',[0.7 0.7 0.7],'MarkerSize',4);
plot(x,x.*f2.p1 + f2.p2,'*-','color',[0.7 0.7 0.7],'MarkerSize',4);
text(128,128.*f1.p1 + f1.p2,['a_{sport 80-90} = ' num2str(round(f1.p1,4))])
text(128,128.*f2.p1 + f2.p2,['a_{comfort 80-90} = ' num2str(round(f2.p1,3))])

h1{1} = scatter(0,0,8,ColorsSpeed2{1},'filled');
h1{2} = scatter(0,0,8,ColorsSpeed2{2},'filled');
h2{1} = scatter(0,0,8,ColorsSpeed1{1},'filled');
h2{2} = scatter(0,0,8,ColorsSpeed1{2},'filled');
legend([h1{1},h1{2},h2{1}, h2{2}],...
    'Sport_{20 km/h - 30 km/h}','Comfort_{20 km/h - 30 km/h}',...
    'Sport_{80 km/h - 90 km/h}','Comfort_{80 km/h - 90 km/h}')
xlim([-200 220])
ylim([-4 4])
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',13)
set(findall(gcf,'Type','text'),'FontSize',9)

xlabel('Steering wheel angle (deg)');
ylabel('Rear wheel angle (deg)')

%% Figure 10a - YawRate
Xfit{1} = []; Yfit{1} = [];
Xfit{2} = []; Yfit{2} = [];

x = linspace(-190,126,20);

figure(); hold on
for cond = 1:2
    for rep = 1:4
        speed1 = strc.Experiment{1}.sub.cond(cond).rep(rep).VehicleSpeed;
        speed_id1 = find(speed1>20 & speed1<30);
        
        X1 = strc.Experiment{1}.sub.cond(cond).rep(rep).SteeringWheelAngle(speed_id1);
        Y1 = strc.Experiment{1}.sub.cond(cond).rep(rep).YawRate(speed_id1);

        speed2 = strc.Experiment{2}.sub.cond(cond).rep(rep).VehicleSpeed;
        speed_id2 = find(speed2>20 & speed2<30);
        
        X2 = strc.Experiment{2}.sub.cond(cond).rep(rep).SteeringWheelAngle(speed_id2);
        Y2 = strc.Experiment{2}.sub.cond(cond).rep(rep).YawRate(speed_id2);
        
        Xfit{cond} = [Xfit{cond};X1;X2];
        Yfit{cond} = [Yfit{cond};Y1;Y2];
    end
end

f1 = fit(Xfit{1},Yfit{1},'poly1');
f2 = fit(Xfit{2},Yfit{2},'poly1');

% Scatter
h1{1} = scatter(Xfit{1},Yfit{1},8,ColorsSpeed2{1},'filled');
h1{2} = scatter(Xfit{2},Yfit{2},8,ColorsSpeed2{2},'filled');

% regression fit
plot(x,x.*f1.p1 + f1.p2,'--','color',[0.7 0.7 0.7]);
plot(x,x.*f2.p1 + f2.p2,'--','color',[0.7 0.7 0.7]);

text(130,30,['a_{sport 20-30} = ' num2str(round(f1.p1,2))]);
text(130,130.*f2.p1 + f2.p2,['a_{comfort 20-30} = ' num2str(round(f2.p1,2))]);

Xfit{1} = []; Yfit{1} = [];
Xfit{2} = []; Yfit{2} = [];

% speed 2
for cond = 1:2
    for rep = 1:4
        speed1 = strc.Experiment{1}.sub.cond(cond).rep(rep).VehicleSpeed;
        speed_id1 = find(speed1>80 & speed1<90);

        X1 = strc.Experiment{1}.sub.cond(cond).rep(rep).SteeringWheelAngle(speed_id1);
        Y1 = strc.Experiment{1}.sub.cond(cond).rep(rep).YawRate(speed_id1);

        speed2 = strc.Experiment{2}.sub.cond(cond).rep(rep).VehicleSpeed;
        speed_id2 = find(speed2>80 & speed2<90);

        X2 = strc.Experiment{2}.sub.cond(cond).rep(rep).SteeringWheelAngle(speed_id2);
        Y2 = strc.Experiment{2}.sub.cond(cond).rep(rep).YawRate(speed_id2);

        Xfit{cond} = [Xfit{cond};X1;X2];
        Yfit{cond} = [Yfit{cond};Y1;Y2];
    end
end

% Scatter
h2{1} = scatter(Xfit{1},Yfit{1},8,ColorsSpeed1{1},'filled');
h2{2} = scatter(Xfit{2},Yfit{2},8,ColorsSpeed1{2},'filled');

% Linear fit
f1 = fit(Xfit{1},Yfit{1},'poly1');
f2 = fit(Xfit{2},Yfit{2},'poly1');

x = linspace(-130,126,20);
plot(x,x.*f1.p1 + f1.p2,'*-','color',[0.7 0.7 0.7],'MarkerSize',4);
plot(x,x.*f2.p1 + f2.p2,'*-','color',[0.7 0.7 0.7],'MarkerSize',4);
text(130,130.*f1.p1 + f1.p2,['a_{sport 80-90} = ' num2str(round(f1.p1,2))])
text(130,130.*f2.p1 + f2.p2,['a_{comfort 80-90} = ' num2str(round(f2.p1,2))])

% Een hack
h1{1} = scatter(0,0,8,ColorsSpeed2{1},'filled');
h1{2} = scatter(0,0,8,ColorsSpeed2{2},'filled');
h2{1} = scatter(0,0,8,ColorsSpeed1{1},'filled');
h2{2} = scatter(0,0,8,ColorsSpeed1{2},'filled');
legend([h1{1},h1{2},h2{1}, h2{2}],...
    'Sport_{20 km/h - 30 km/h}','Comfort_{20 km/h - 30 km/h}',...
    'Sport_{80 km/h - 90 km/h}','Comfort_{80 km/h - 90 km/h}')
xlim([-180 180])
ylim([-35 50])
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',13)
set(findall(gcf,'Type','text'),'FontSize',9)
xlabel('Steering wheel angle (deg)');
ylabel('Yaw rate (deg/s)')

%% Figure 11a - Lateral Acceleration
Xfit{1} = []; Yfit{1} = [];
Xfit{2} = []; Yfit{2} = [];

figure(); hold on
for cond = 1:2
    for rep = 1:4
        speed1 = strc.Experiment{1}.sub.cond(cond).rep(rep).VehicleSpeed;
        speed_id1 = find(speed1>20 & speed1<30);
        
        X1 = strc.Experiment{1}.sub.cond(cond).rep(rep).SteeringWheelAngle(speed_id1);
        Y1 = strc.Experiment{1}.sub.cond(cond).rep(rep).TransversalAccelera(speed_id1).*9.80665;

        speed2 = strc.Experiment{2}.sub.cond(cond).rep(rep).VehicleSpeed;
        speed_id2 = find(speed2>20 & speed2<30);
        
        X2 = strc.Experiment{2}.sub.cond(cond).rep(rep).SteeringWheelAngle(speed_id2);
        Y2 = strc.Experiment{2}.sub.cond(cond).rep(rep).TransversalAccelera(speed_id2).*9.80665;

        Xfit{cond} = [Xfit{cond};X1;X2];
        Yfit{cond} = [Yfit{cond};Y1;Y2];
    end
end

f1 = fit(Xfit{1},Yfit{1},'poly1');
f2 = fit(Xfit{2},Yfit{2},'poly1');

% Scatter
h1{1} = scatter(Xfit{1},Yfit{1},8,ColorsSpeed2{1},'filled');
h1{2} = scatter(Xfit{2},Yfit{2},8,ColorsSpeed2{2},'filled');

% regression fit
x = linspace(-200,145,20);
plot(x,x.*f1.p1 + f1.p2,'--','color',[0.7 0.7 0.7]);
plot(x,x.*f2.p1 + f2.p2,'--','color',[0.7 0.7 0.7]);

text(150,150.*f1.p1 + f1.p2,['a_{sport 20-30} = ' num2str(round(f1.p1,3))]);
text(150,145.*f2.p1 + f2.p2,['a_{comfort 20-30} = ' num2str(round(f2.p1,3))]);

Xfit{1} = []; Yfit{1} = [];
Xfit{2} = []; Yfit{2} = [];

% Speed 2
for cond = 1:2
    for rep = 1:4
        speed1 = strc.Experiment{1}.sub.cond(cond).rep(rep).VehicleSpeed;
        speed_id1 = find(speed1>80 & speed1<90);

        X1 = strc.Experiment{1}.sub.cond(cond).rep(rep).SteeringWheelAngle(speed_id1);
        Y1 = strc.Experiment{1}.sub.cond(cond).rep(rep).TransversalAccelera(speed_id1).*9.80665;

        speed2 = strc.Experiment{2}.sub.cond(cond).rep(rep).VehicleSpeed;
        speed_id2 = find(speed2>80 & speed2<90);

        X2 = strc.Experiment{2}.sub.cond(cond).rep(rep).SteeringWheelAngle(speed_id2);
        Y2 = strc.Experiment{2}.sub.cond(cond).rep(rep).TransversalAccelera(speed_id2).*9.80665;

        Xfit{cond} = [Xfit{cond};X1;X2];
        Yfit{cond} = [Yfit{cond};Y1;Y2];
    end
end

h2{1} = scatter(Xfit{1},Yfit{1},8,ColorsSpeed1{1},'filled');
h2{2} = scatter(Xfit{2},Yfit{2},8,ColorsSpeed1{2},'filled');

% Linear fit
f1 = fit(Xfit{1},Yfit{1},'poly1');
f2 = fit(Xfit{2},Yfit{2},'poly1');

x = linspace(-200,50,20);
plot(x,x.*f1.p1 + f1.p2,'*-','color',[0.7 0.7 0.7],'MarkerSize',4);
text(52,52.*f1.p1 + f1.p2,['a_{sport 80-90} = ' num2str(round(f1.p1,4))])

plot(x,x.*f2.p1 + f2.p2,'*-','color',[0.7 0.7 0.7],'MarkerSize',4);
text(52,52.*f2.p1 + f2.p2,['a_{comfort 80-90} = ' num2str(round(f2.p1,3))])

h1{1} = scatter(0,0,8,ColorsSpeed2{1},'filled');
h1{2} = scatter(0,0,8,ColorsSpeed2{2},'filled');
h2{1} = scatter(0,0,8,ColorsSpeed1{1},'filled');
h2{2} = scatter(0,0,8,ColorsSpeed1{2},'filled');
legend([h1{1},h1{2},h2{1}, h2{2}],...
    'Sport_{20 km/h - 30 km/h}','Comfort_{20 km/h - 30 km/h}',...
    'Sport_{80 km/h - 90 km/h}','Comfort_{80 km/h - 90 km/h}')
xlim([-170 200])
ylim([-5 7.5])
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',13)
set(findall(gcf,'Type','text'),'FontSize',9)
xlabel('Steering wheel angle (deg)');
ylabel('Lateral acceleration (m/s^2)')
end