function [ ] = QcarOptimisation( )
%% Initialize
xl_fun1 = 0;
xh_fun1 = 1e10;

% Init given Renault parameters
ms = 304;
ks = 29100;
mu = 70;
bu = 150;
ku = 264090;

% Init damping for x{1} = HW_Comf, x{2} = HW_sport, x{3} = RR_comf, 
% x{4} = RR_sport;
x = cell(4,1); 

% The frequencies that are compared in the optimization function.
load w w;

% The suspension travel emperical data for all four repetitions combined
% in one vector. Comf = Comfort, HW = Highway, RR = Rural road
load Comf_HW Comf_HW;
load Comf_RR Comf_RR;
load Sport_HW Sport_HW;
load Sport_RR Sport_RR;

%% Optimization

options = optimset('PlotFcns',@optimplotfval);
for i = 1:4
    [x{i}, ~] = fminbnd(@(x)fun_1(x,i),xl_fun1,xh_fun1,options);
end

%% plot using the optimized b values
figure();
for j = 1:2
    if j == 1 % HW
        Csp_comf = 1.6e-7;
        Csp_sport = Csp_comf;
        N_comf = 2.59;
        N_sport = N_comf;
        bcomfort = x{1};
        bsport = x{2}; 
        V = 20; % m/s        
    elseif j == 2 % RR
        Csp_comf = 7.5e-7;
        Csp_sport = Csp_comf;
        N_comf = 2.32;
        N_sport = N_comf;
        bcomfort = x{3};%Comf_highway
        bsport = x{4};%Sport_highway
        V = 11; % m/s
    end
    psd_road_comfort = (Csp_comf*V^(N_comf-1))./(w.^N_comf);
    psd_road_sport = (Csp_sport*V^(N_sport-1))./(w.^N_sport);
    
    s = tf('s');
    H_comfort = (-ms*bu*s^3-ms*ku*s^2)/((ms*s^2+bcomfort*s+ks)*(mu*s^2+(bcomfort+bu)*s+(ks+ku))-(bcomfort*s+ks)*(bcomfort*s+ks));
    H_sport = (-ms*bu*s^3-ms*ku*s^2)/((ms*s^2+bsport*s+ks)*(mu*s^2+(bsport+bu)*s+(ks+ku))-(bsport*s+ks)*(bsport*s+ks));
    
    subplot(1,2,j, 'XScale', 'log', 'YScale', 'log')
    
    % plot the results
    if j == 1 % HW
        loglog(w,Comf_HW,'-^','Color',[0.5 0.5 1],'MarkerSize',8,'MarkerFaceColor',[0.4 0.4 1],'LineWidth',1); hold on;
        loglog(w,Sport_HW,'-o','Color',[1 0.5 0.5],'MarkerSize',8,'MarkerFaceColor',[1 0.4 0.4],'LineWidth',1)
        Name1 = 'Comfort_{HW}';
        Name2 = 'Sport_{HW}';
    elseif j == 2 % RR
        loglog(w,Comf_RR,'-^','Color',[0.5 0.5 1],'MarkerSize',8,'MarkerFaceColor',[0.4 0.4 1],'LineWidth',1); hold on;
        loglog(w,Sport_RR,'-o','Color',[1 0.5 0.5],'MarkerSize',8,'MarkerFaceColor',[1 0.4 0.4],'LineWidth',1)
        Name1 = 'Comfort_{RR}';
        Name2 = 'Sport_{RR}';
    end
    
    [Val, ~] = freqresp(H_comfort,w,'Hz');
    mag = squeeze(abs(Val(1,1,:)));
    loglog(w,mag.*psd_road_comfort,'b:','MarkerFaceColor','b','Linewidth',4)
    hold on;
    
    [Val, ~] = freqresp(H_sport,w,'Hz');
    mag = squeeze(abs(Val(1,1,:)));
    loglog(w,mag.*psd_road_sport,'r-.','MarkerFaceColor','r','Linewidth',4)
    text(1,0.4e-6,{'bs',['--- = ' num2str(bsport/bcomfort)],'bc'});
    xlim([0.7 12])
    ylim([0.5e-7 1e-4])
    legend(Name1,Name2,['b_{comfort} = ' num2str(round(bcomfort)) ' Ns/m'],['b_{sport} = ' num2str(round(bsport)) ' Ns/m']);
    ylabel({'Power spectral density','suspension travel',' (m^2/Hz)'})
    xlabel('Frequency (Hz)')
    
    % natural frequency of sprung mass
    wn_s = sqrt(ks*ku / (ks + ku)/ms);
    % natural frequency of sprung mass, Hz
    fn_s = wn_s / 2 / pi;
    % natural frequency of unsprung mass, Hz
    fn_u = sqrt((ks + ku)/mu) / 2 / pi;
end

% Display the natural frequencies for the sprung and unsprung mass
disp(['F_s = ' num2str(fn_s) ' and F_u = ' num2str(fn_u)]);
