function [ ] = SignalCheck(strc, Road_Name )
% This file creates the figure 6 & 7 (Cohen's d ranking plot for both 
% the rural road and the highway. From line 208, figures 4 and 5 are 
% plotted. This functions uses the "subtightplot" to reduce the gaps 
% between subplots and thereby reducing the whitespace (Nievinski 2013). 
% see https://nl.mathworks.com/matlabcentral/fileexchange/39664-subtightplot  

if strcmp(Road_Name,'RuralRoad')
    strc = strc.Experiment{1};
elseif strcmp(Road_Name,'Highway')
    strc = strc.Experiment{2};
else
    error('No match found for Road_Name, please check the name for typo''s')
end
%% Initialize conditions
% Create Excel File with differences between the two conditions
do.Ranking        = true;
PlotMetricRating = true;
PlotImportantRaw = true;
FieldList        = fields(strc.sub(1).cond(1).rep(1)); % create Fieldlist

% Initialize the values used in the ranking calculations
Y_mean           = nan(1772,4);
Y_SD             = nan(1772,4);
Y_squared        = nan(1772,4);
Y_meanabsdiff    = nan(1772,4);
FieldListCohenD  = cell(1772,1);
FieldList2       = cell(1772,1);
Rowcounter       = 1;
Count            = 1;

%% Start ranking
if do.Ranking
    disp('Going through all CAN signals to do ranking');
    for i = 1:length(FieldList)
        if ~strcmp(FieldList(i),'gps')
            fprintf('Ranking data %s %i/%i \r',Road_Name,i,length(FieldList))
            for cond = 1:2
                    for rep = 1:4
                        eval(['y = strc.sub(1).cond(cond).rep(rep).' FieldList{i} ';']);
                        
                        % Create matrix containing the mean, SD, squared 
                        % and mean abs difference for each signal in the
                        % 'Fieldlist' (i.e., for all the signals in the CAN
                        % data)
                        Y_mean(Rowcounter,rep) = mean(y);
                        Y_SD(Rowcounter,rep) = std(y);
                        Y_squared(Rowcounter,rep) = mean(y.^2);
                        Y_meanabsdiff(Rowcounter,rep) = mean(abs(diff(y)));
                    end
                Rowcounter = Rowcounter + 1;
            end
            SD_pool_mean = sqrt(3/6*std(Y_mean(Rowcounter-2,:))^2 + ...
                3/6*std(Y_mean(Rowcounter-1,:))^2);
            
            Y_CohenD.mean(i) = (mean(Y_mean(Rowcounter-2,:)) - ...
                mean(Y_mean(Rowcounter-1,:)))/ SD_pool_mean;
            
            SD_pool_meanabsdiff = sqrt(3/6*std(Y_meanabsdiff(Rowcounter-2,:))^2 + ...
                3/6*std(Y_meanabsdiff(Rowcounter-1,:))^2);
            
            Y_CohenD.meanabsdiff(i) = (mean(Y_meanabsdiff(Rowcounter-2,:)) - ...
                mean(Y_meanabsdiff(Rowcounter-1,:)))/ SD_pool_meanabsdiff;
            
            SD_pool_SD = sqrt(3/6*std(Y_SD(Rowcounter-2,:))^2 + ...
                3/6*std(Y_SD(Rowcounter-1,:))^2);
            
            Y_CohenD.SD(i) = (mean(Y_SD(Rowcounter-2,:)) - ...
                mean(Y_SD(Rowcounter-1,:)))/ SD_pool_SD;
            
            FieldListCohenD(Count) = FieldList(i); Count = Count + 1;
        end
    end
    
    for i = 1:length(FieldList)
        FieldList2(3*i-2,1) =   FieldList(i);
    end
    
    [~, NanId] = find(isnan(Y_CohenD.mean)== 1);
    Y_CohenD.mean(NanId) = 0;
    
    [~, InfId] = find(isinf(Y_CohenD.mean)== 1);
    Y_CohenD.mean(InfId) = 0;
    
    [SortY1, I1] = sort(abs(Y_CohenD.mean),'ascend');
    SortedFieldList1= FieldListCohenD(I1);
    Sorted_Y_CohenD.mean = Y_CohenD.mean(I1);
    
    [~, NanId] = find(isnan(Y_CohenD.meanabsdiff)== 1);
    Y_CohenD.meanabsdiff(NanId) = 0;
    
    [SortY2, I2] = sort(abs(Y_CohenD.meanabsdiff),'ascend');
    SortedFieldList2= FieldListCohenD(I2);
    Sorted_Y_CohenD.meanabsdiff = Y_CohenD.SD(I2);
    
    [~, NanId] = find(isnan(Y_CohenD.SD)== 1);
    Y_CohenD.SD(NanId) = 0;
    
    [SortY3, I3] = sort(abs(Y_CohenD.SD),'ascend');
    SortedFieldList3= FieldListCohenD(I3);
    Sorted_Y_CohenD.SD = Y_CohenD.SD(I3); 
end

%% Cohen's d rating plot (Figure 6 and 7 of VSDJ manuscript)
if PlotMetricRating
    NumPlot = 30;
    limx = 19;
    fontsize = 10;
    
    % Plot Mean subplot
    figure();
    subplot(1,3,1); hold on;
    
    for i=1:NumPlot
        id = length(SortY1)-NumPlot+i;
        h = barh(i,SortY1(id));
        if Sorted_Y_CohenD.mean(id) > 0
            col = 'r';
            h1 = h;
            sign = 1;
        else
            col = [0.6 0.6 1];
            h2 = h;
            sign = -1;
        end
        if h.YData < limx
            text(h.YData,h.XData,[' ' num2str(round(sign*h.YData,1))])
        else
            text(limx,h.XData,[' ' num2str(round(sign*h.YData,1))])
        end
        set(h, 'FaceColor', col)
    end
    
    PlotLabels = name2label( SortedFieldList1(end-NumPlot+1:end) );
    ylim([0 NumPlot+1])
    xlim([0 limx])
    set(gca,'TickLabelInterpreter', 'none');
    set(gca,'ytick',1:NumPlot);
    set(gca,'YTickLabel',PlotLabels,'FontSize',fontsize);
    legend([h1 h2],'d > 0 (Sport > Comfort)','d < 0 (Sport < Comfort)','Location','southeast');
    title({'Mean'},'FontSize',13)
    xlabel('Cohen''s d')
    
    % Plot abs diff subplot
    subplot(1,3,3); hold on;
    
    for i=1:NumPlot
        id = length(SortY2)-NumPlot+i;
        h = barh(i,SortY2(id));
        if Sorted_Y_CohenD.meanabsdiff(id) > 0
            col = 'r';
            h1 = h;
            sign = 1;
        else
            col = [0.6 0.6 1];
            h2 = h;
            sign = -1;
        end
        set(h, 'FaceColor', col)
        text(h.YData,h.XData,[' ' num2str(round(sign*h.YData,1))])
    end
    PlotLabels = name2label( SortedFieldList2(end-NumPlot+1:end) );
    
    legend([h1 h2],'d > 0 (Sport > Comfort)','d < 0 (Sport < Comfort)','Location','southeast');%,...
    ylim([0 NumPlot+1])
    xlim([0 limx])
    set(gca,'TickLabelInterpreter', 'none');
    set(gca,'ytick',1:NumPlot);
    set(gca,'YTickLabel',PlotLabels,'FontSize',fontsize);
    title({'mean abs diff'},'FontSize',13)
    xlabel('Cohen''s d')
    
    % Plot SD subplot
    subplot(1,3,2); hold on;
    for i=1:NumPlot
        id = length(SortY3)-NumPlot+i;
        h = barh(i,SortY3(id));
        if Sorted_Y_CohenD.SD(id) > 0
            col = 'r';
            h1 = h;
            sign = 1;
        else
            col = [0.6 0.6 1];
            h2 = h;
            sign = -1;
        end
        set(h, 'FaceColor', col)
        text(h.YData,h.XData,[' ' num2str(round(sign*h.YData,1))])
    end
    PlotLabels = name2label( SortedFieldList3(end-NumPlot+1:end) );
    
    legend([h1 h2],'d > 0 (Sport > Comfort)','d < 0 (Sport < Comfort)','Location','southeast');%,...
    ylim([0 NumPlot+1])
    xlim([0 limx])
    set(gca,'TickLabelInterpreter', 'none');
    set(gca,'ytick',1:NumPlot);
    set(gca,'YTickLabel',PlotLabels,'FontSize',fontsize);
    title({'SD'},'FontSize',13)
    xlabel('Cohen''s d')
    
    if strcmp(Road_Name,'RuralRoad')
        sgtitle('Rural road')
    elseif strcmp(Road_Name,'Highway')
        sgtitle('Highway')
    else
        error('No match found for Road_Name, please check the name for typo''s')
    end
end

%% Figure 4 and 5 in the paper
if PlotImportantRaw
    if strcmp(Road_Name,'RuralRoad')
        xmin = 0.3;  xmax = 9.1;
        % Used zoom xlim in paper: xmin = 4.3; xmax = 4.9;
    elseif strcmp(Road_Name,'Highway')
        xmin = 0.3;  xmax = 14; %
        % Used zoom xlim in paper: xmin = 7.5; xmax = 8.5;
    else
        error('No match found for Road_Name, please check the name for typo''s')
    end
    
    ConditionPlotList = {'VehicleSpeed','EngineRPM',...
        'BrakingPressure',...
        'SteeringWheelAngle',...
        'YawRate',...
        'RearWheelAnglePosit'};
    
    LabelList = {{'Speed';'(km/h)'},{'Engine';'speed';'(RPM)'},...
        {'Brake';'Pressure';'(bar)'},...
        {'SW angle';'(deg)'},...
        {'Yaw rate';'(deg/s)'},...
        {'Rear wheel';'angle';'(deg)'}};
    X = strc.CombinedData.Rp;
    
    figure();
    for i = 1:length(ConditionPlotList)
        subtightplot(length(ConditionPlotList),1,i,[0.015 0.05], [0.07 0.02], [0.07 0.01]); hold on;
        eval(['Y1 = strc.CombinedData.cond{1}.' ConditionPlotList{i} ';']);
        eval(['Y2 = strc.CombinedData.cond{2}.' ConditionPlotList{i} ';']);
        
        if i == 4 || i == 8
            plot(X,Y2.mean,'color',[0.6 0.6 1],'LineWidth',1.3);
            plot(X,Y1.mean,'r','LineWidth',1.3);
        else
            plot(X,Y1.mean,'r','LineWidth',1.3);
            plot(X,Y2.mean,'color',[0.6 0.6 1],'LineWidth',1.3);
        end
        xlim([xmin xmax]);
        
        if i == 1
            legend('Sport','Comfort','Orientation','horizontal','Location','north');
            if strcmp(Road_Name,'RuralRoad')
                ylim([0 80])
                yticks([0 70])
                yticklabels({'0','70'})
            elseif strcmp(Road_Name,'Highway')
                ylim([0 130])
                yticks([0 120])
                yticklabels({'0','120'})
            end
        end
        if i == 2 % RPM
            if strcmp(Road_Name,'RuralRoad')
                ylim([800 3000])
                yticks([800 2800])
                yticklabels({'800','2800'})
            elseif strcmp(Road_Name,'Highway')
                ylim([1000 3000])
                yticks([1000 2500])
                yticklabels({'1000','2500'})
            end
        end
        if i == 3 % Brake
            if strcmp(Road_Name,'RuralRoad')
                ylim([0 15]);
                yticks([0 10])
                yticklabels({'0','10'})
            elseif strcmp(Road_Name,'Highway')
                ylim([0 20]);
                yticks([0 15])
                yticklabels({'0','15'})
            end
        end
        if i == 4 % SW angle
            if strcmp(Road_Name,'RuralRoad')
                ylim([-80 80]);
                yticks([-80 70])
                yticklabels({'-80','70'})
            elseif strcmp(Road_Name,'Highway')
                ylim([-60 60]);
                yticks([-60 50])
                yticklabels({'-60','50'})
            end
        end
        if i == 5 % yawrate
            if strcmp(Road_Name,'RuralRoad')
                ylim([-20 20]);
                yticks([-20 15])
                yticklabels({'-20','15'})
            elseif strcmp(Road_Name,'Highway')
                ylim([-20 20]);
                yticks([-20 15])
                yticklabels({'-20','15'})
            end
        end
        if i == 6 % rear wheel
            if strcmp(Road_Name,'RuralRoad')
                ylim([-3 3]);
                yticks([-3 2])
                yticklabels({'-3','2'})
            elseif strcmp(Road_Name,'Highway')
                ylim([-2 2]);
                yticks([-2 1.5])
                yticklabels({'-2','1.5'})
            end
        end
        
        if i == length(ConditionPlotList)
            xlabel('Distance (km)')
        else
            set(gca,'XTick',[]); box off;
        end
        ylabel(LabelList{i},'Interpreter','none');
    end
end
