function fig_handle=plt_error_bars_cohenD( DATA,  x_label, y_label, tick_labels,...
    width,plotCI,plt_individual_lines)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Code to create cohen d appendix Figure
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Init
if isempty(width)
   width = 0.1; 
end

% marker = ['s','d','o','*','<','^','>','v'];
SD     = nan(2,1);  % Standard deviation
means  = nan (2,1); % Mean of the data points
xsmall = cell(2,1); % x position of individual data points (used for small scatter effect around condition plot)

[color{1},color{2},color{3},color{4},color{5}, ...
    color{6},color{7},color_l{1},color_l{2},color_l{3},...
    color_l{4},color_l{5},color_l{6},color_l{7}] = specify_colors();

for cond = 1:length(DATA(1,:))
        means(cond,1)=mean(DATA(:,cond),'omitnan');
        SD(cond,1) = std(DATA(:,cond));
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Plot error bars
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% determine the nr of conditions:
nr_cond = size(means,1);

% Open the figure
fig_handle = figure(); hold on;

% Counter for error bar position
i=1; 

for cond=1:nr_cond
        xsmall{cond} = i + rand(length(DATA(:,cond)),1).*0.16 - 0.08;
        
        % To plot the data in the plot
        plot(xsmall{cond},DATA(:,cond),'*','color',color_l{cond})
        
        if (plotCI) 
            % draw the polygons in CW direction, starting upper left corner
            x_pos = [i-width i+width i+width i-width];
            y_max = means(cond)+SD(cond);
            y_min = means(cond)-SD(cond);
            %y_pos = [y_max y_max y_min y_min];
            plot((i)*[1,1],[y_min, y_max],'color',color{cond});
            plot([x_pos(1) x_pos(2)],y_min*[1,1],'color',color{cond});
            plot([x_pos(1) x_pos(2)],y_max*[1,1],'color',color{cond});
        end
        i=i+1;
end

% Plot the individual lines
if plt_individual_lines
    plot([xsmall{1} xsmall{2}]', [DATA(:,1) DATA(:,2)]','-','color',[0.9 0.9 0.9])
end

%% plot mean lines
i=1; % counter for error bar position
for cond=1:nr_cond
        % plot the mean line
        x=[i-width*1.5 i+width*1.5];
        y=[means(cond) means(cond)];
        plot(x,y,'k','LineWidth',2+width, 'color',color{cond});
        i=i+1;
end
set(gca,'xtick',1:nr_cond);
set(gca,'XTickLabel',tick_labels,'FontSize',14);
xlabel(x_label,'FontSize',16);
ylabel(y_label,'FontSize',16);

% fix the axis limits
xlim([0.5 i-0.5]);
ylimits = get(gca,'yLim');

% make sure the ylimits stay where they are
ylim(ylimits);


%% Cohen D visualization part
SD_pool_mean = sqrt(3/6*std(DATA(:,1))^2 + ...
            3/6*std(DATA(:,2))^2);
CohenD = (mean(DATA(:,1)) - mean(DATA(:,2)))/ SD_pool_mean;

text(1.2,max(max(DATA))+0.03,['Cohen''s d = ' num2str(round(CohenD,2))])

Y1 = mean(DATA(:,2));
for i = 1:floor(CohenD)
       Y2 = Y1 + sign(CohenD)*SD_pool_mean;
       plot([1.5 1.5],[Y1 Y2],'-.k','LineWidth',0.5);
       plot([1.4 1.6],[Y1 Y1],'-.k','LineWidth',0.5);
       plot([1.4 1.6],[Y2 Y2],'-.k','LineWidth',0.5);
       Y1 = Y2;
end
Y2 = Y1 + rem(CohenD,1)*SD_pool_mean*sign(CohenD);
plot([1.5 1.5],[Y1 Y2],'-.k','LineWidth',0.5);

% These define the placement and size of the brace
x = 1.62;
y1 = mean(DATA(:,2)) + sign(CohenD)*SD_pool_mean*5;
y2 = mean(DATA(:,2)) + sign(CohenD)*SD_pool_mean*6;
width = 0.2;

% Make some x-data and y-data
line_x = x  + [0, 0.5, 0.5, 1, 0.5, 0.5, 0]*width;
line_y = y1 + [0, 0.02, 0.48, 0.5, 0.52, 0.98, 1]*(y2-y1);

% Draw the brace and some text, too, for fun.
line(line_x, line_y, 'Color', 'k')
text(x+1.1*width, y1 + 0.5*(y2-y1),...
    {'One time the pooled','standard deviation',...
    ['(s = ' num2str(round(SD_pool_mean,2)), ')'],...
    ['fits ' num2str(round(CohenD,2)) ' between'],'the two means'});
